# jaustin

A set of core Python utilities for Python programming and machine learning. 

This library is divided into several modules:

- color: a set of functions for printing colored text to the console
- io: a set of functions for handling file IO
- timers: a set of timers and meters for measuring performance
- cache: a set of useful caching mechanisms for improving performance

## Contact

For more information, please contact jacob.austin@columbia.edu.
